// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_COMPONENTS_SHORTCUT_VIEWER_VIEWS_KEYBOARD_SHORTCUT_ITEM_LIST_VIEW_H_
#define ASH_COMPONENTS_SHORTCUT_VIEWER_VIEWS_KEYBOARD_SHORTCUT_ITEM_LIST_VIEW_H_

#include "ui/views/view.h"

namespace keyboard_shortcut_viewer {

// Displays a list of KeyboardShortcutItemView. In search result page, all
// KeyboardShortcutItemView are grouped by ShortcutCategory and can be scrolled
// in a single page. A text label to indicate the ShortcutCategory will be
// diplayed at the beginning of the group of KeyboardShortcutItemView.
class KeyboardShortcutItemListView : public views::View {
 public:
  KeyboardShortcutItemListView();
  ~KeyboardShortcutItemListView() override = default;

  // In search result page, a text label is added at the beginning of the group
  // of KeyboardShortcutItemView to indicate the ShortcutCategory.
  void AddCategoryLabel(const base::string16& text);

  // Add a horizontal line to separate the KeyboardShortcutItemView. The last
  // item in the list is not followed by the horizontal line.
  void AddHorizontalSeparator();

 private:
  DISALLOW_COPY_AND_ASSIGN(KeyboardShortcutItemListView);
};

}  // namespace keyboard_shortcut_viewer

#endif  // ASH_COMPONENTS_SHORTCUT_VIEWER_VIEWS_KEYBOARD_SHORTCUT_ITEM_LIST_VIEW_H_
